@@ -2,7 +2,9 @@ expected_CV <- function (strata) {
   M_h <- S_h <- NULL
   if (is.null(strata$SOLUZ)) stop("There is no allocation of units in strata")
   ndom <- length(unique(strata$DOM1))
-  nvars <- (ncol(strata) - 6) / 2
+  nvarX <- length(grep("X",colnames(strata)))
+  nstr <- length(grep("STR",colnames(strata)))
+  nvars <- (ncol(strata) - nstr - 5 - nvarX) / 2
   cv <- matrix(NA,nrow=ndom,ncol=nvars)
   colnames(cv) <- paste("cv(Y",c(1:nvars),")",sep="")
   rownames(cv) <- paste("DOM",c(1:ndom),sep="")
@@ -23,6 +25,6 @@ expected_CV <- function (strata) {
       cv[k,j] <- CV 
     }
   }
-  cv <- round(cv,3)
+  cv <- round(cv,7)
   cv
 }
\ No newline at end of file
